@@ -30,9 +30,9 @@ class GeoCoord:
               the fractional values (0.17) will be added to the second variable.
             second (scalar) - decimal minutes.
         '''
-        self.degree = degree
-        self.minute = minute
-        self.second = second
+        self.degree = float(degree)
+        self.minute = float(minute)
+        self.second = float(second)
         self._update() # Clean up each variable and make them consistent
         
     def set_minute(self, minute):
